<?php

namespace Drupal\toolbar_visibility\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Toolbar Visibility Settings Form.
 *
 * @package Drupal\toolbar_visibility\Form
 */
class ToolbarVisibilitySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'toolbar_visibility.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'toolbar_visibility_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('toolbar_visibility.settings');

    $themes = [];
    if (!empty($config->get('themes'))) {
      $themes = $config->get('themes');
    }

    $list_themes = \Drupal::service('theme_handler')->listInfo();
    $all_themes = [];
    foreach ($list_themes as $list) {
      $all_themes[$list->getName()] = $list->getName();
    }
    $form['themes'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select theme(s) where you want to remove Toolbar'),
      '#options' => $all_themes,
      '#default_value' => $themes,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $values = $form_state->cleanValues()->getValues();
    $this->config('toolbar_visibility.settings')
      ->set('themes', $values['themes'])
      ->save();
  }

}
